# Wheeled Robot Environments

## Tasks

> No tasks are implemented at the moment.

## Demos

### Perseverance

```bash
.docker/run.bash -e SRB_SCENARIO=mars scripts/teleop.py --env perseverance
```

![](../../_images/envs/perseverance.jpg)
